==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Content/language/lang-german.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/



define("_PREVIOUS","Vorherige Seite");
define("_NEXT","N&auml;chste Seite");


define("_PAGE","Seite");
define("_DEACTIVATE","Deaktivieren");
define("_ACTIVATE","Aktivieren");
define("_PUBLISHEDON","Publiziert am");
define("_PAGESLIST","Seiten gelisted");
define("_LISTOFCONTENT","Zeige den vorhanden Inhalt in");
define("_YOURADMINLIST","Du bist Administrator: nachfolgend die inaktiven Seiten:");
define("_COPYRIGHT","Copyright &copy; by $sitename. All Right Reserved.");
define("_CONTENTCATEGORIES","Available Content Categories");
define("_NONCLASSCONT","Non Categorized Content");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Content/language/lang-german.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Vorherige Seite");
define("_NEXT","N&auml;chste Seite");
define("_PAGE","Seite");
define("_DEACTIVATE","Deaktivieren");
define("_ACTIVATE","Aktivieren");
define("_PUBLISHEDON","Publiziert am");
define("_PAGESLIST","Seiten gelisted");
define("_LISTOFCONTENT","Zeige den vorhanden Inhalt in");
define("_YOURADMINLIST","Du bist Administrator: nachfolgend die inaktiven Seiten:");
define("_COPYRIGHT","Copyright &copy; by");
define("_COPYRIGHT2","All Right Reserved.");
define("_CONTENTCATEGORIES","Available Content Categories");
define("_NONCLASSCONT","Non Categorized Content");

?>
